aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPExporter.m
diff options
context:
space:
mode:
Diffstat (limited to 'Source/SPExporter.m')
-rw-r--r--Source/SPExporter.m10
1 files changed, 7 insertions, 3 deletions
diff --git a/Source/SPExporter.m b/Source/SPExporter.m
index a5a1f834..f99b35c3 100644
--- a/Source/SPExporter.m
+++ b/Source/SPExporter.m
@@ -34,16 +34,20 @@
@synthesize exportOutputEncoding;
/**
* Initialize an instance of the exporter setting some default values
*/
-- (id)init
+- (id)initWithDelegate:(id)exportDelegate
{
- if ((self == [super init])) {
+ if ((self = [super init])) {
+ [self setDelegate:exportDelegate];
+
[self setExportProgressValue:0];
[self setExportProcessIsRunning:NO];
// Default the output encoding to UTF-8
[self setExportOutputEncoding:NSUTF8StringEncoding];
+
+ [self setDidEndSelector:@selector(csvDataAvailable:)];
}
return self;
@@ -34,16 +34,20 @@
/**
- * Initialize an instance of the exporter setting some default values
+ * Initialise an instance of SPCSVExporter using the supplied delegate and set some default values.
*/